darkhistory.electrons.ics.BE_integrals.F2 — DarkHistory documentation

# darkhistory.electrons.ics.BE_integrals.F2

`darkhistory.electrons.ics.BE_integrals.` `F2`(a, b, tol=1e-10)

  Definite integral of x^2/[(exp(x) - 1)]

  Parameters: | a : ndarray Lower limit of integration. Can be either 1D or 2D. b : ndarray Upper limit of integration. Can be either 1D or 2D. tol : float The relative tolerance to be reached. Default is 1e-10.
  Returns: | float The resulting integral.

#### Previous topic

darkhistory.electrons.ics.BE_integrals.F1

#### Next topic

darkhistory.electrons.ics.BE_integrals.F_inv

### This Page

Show Source